imitation.data package
======================

Submodules
----------

imitation.data.buffer module
----------------------------

.. automodule:: imitation.data.buffer

imitation.data.rollout module
-----------------------------

.. automodule:: imitation.data.rollout

imitation.data.types module
---------------------------

.. automodule:: imitation.data.types

imitation.data.wrappers module
------------------------------

.. automodule:: imitation.data.wrappers


Module contents
---------------

.. automodule:: imitation.data
